from collections.abc import Callable
from typing import Any

GROUP_NAME: str
DEFAULT_KEYWORDS: Any
DEFAULT_MAPPING: Any
empty_msgid_warning: str

def extract_from_dir(
    dirname: Any | None = ...,
    method_map=...,
    options_map: Any | None = ...,
    keywords=...,
    comment_tags=...,
    callback: Any | None = ...,
    strip_comment_tags: bool = ...,
    directory_filter: Callable[[str], bool] | None = ...,
) -> None: ...
def check_and_call_extract_file(
    filepath, method_map, options_map, callback, keywords, comment_tags, strip_comment_tags, dirpath: Any | None = ...
) -> None: ...
def extract_from_file(
    method, filename, keywords=..., comment_tags=..., options: Any | None = ..., strip_comment_tags: bool = ...
): ...
def extract(
    method, fileobj, keywords=..., comment_tags=..., options: Any | None = ..., strip_comment_tags: bool = ...
) -> None: ...
def extract_nothing(fileobj, keywords, comment_tags, options): ...
def extract_python(fileobj, keywords, comment_tags, options): ...
def extract_javascript(fileobj, keywords, comment_tags, options) -> None: ...
