from _typeshed import Incomplete

def spawn(
    cmd: list[str], search_path: bool = ..., verbose: bool = ..., dry_run: bool = ..., env: Incomplete | None = ...
) -> None: ...
def find_executable(executable: str, path: str | None = ...) -> str | None: ...
