from typing import Any

EOF: Any
E: Any
namespaces: Any
scopingElements: Any
formattingElements: Any
specialElements: Any
htmlIntegrationPointElements: Any
mathmlTextIntegrationPointElements: Any
adjustSVGAttributes: Any
adjustMathMLAttributes: Any
adjustForeignAttributes: Any
unadjustForeignAttributes: Any
spaceCharacters: Any
tableInsertModeElements: Any
asciiLowercase: Any
asciiUppercase: Any
asciiLetters: Any
digits: Any
hexDigits: Any
asciiUpper2Lower: Any
headingElements: Any
voidElements: Any
cdataElements: Any
rcdataElements: Any
booleanAttributes: Any
entitiesWindows1252: Any
xmlEntities: Any
entities: Any
replacementCharacters: Any
tokenTypes: Any
tagTokenTypes: Any
prefixes: Any

class DataLossWarning(UserWarning): ...
class _ReparseException(Exception): ...
