from typing import Any

MIN_ROW: int
MIN_COLUMN: int
MAX_COLUMN: int
MAX_ROW: int
PACKAGE_PROPS: str
PACKAGE_XL: str
PACKAGE_RELS: str
PACKAGE_THEME: Any
PACKAGE_WORKSHEETS: Any
PACKAGE_CHARTSHEETS: Any
PACKAGE_DRAWINGS: Any
PACKAGE_CHARTS: Any
PACKAGE_IMAGES: Any
PACKAGE_WORKSHEET_RELS: Any
PACKAGE_CHARTSHEETS_RELS: Any
PACKAGE_PIVOT_TABLE: Any
PACKAGE_PIVOT_CACHE: Any
ARC_CONTENT_TYPES: str
ARC_ROOT_RELS: Any
ARC_WORKBOOK_RELS: Any
ARC_CORE: Any
ARC_APP: Any
ARC_WORKBOOK: Any
ARC_STYLE: Any
ARC_THEME: Any
ARC_SHARED_STRINGS: Any
ARC_CUSTOM_UI: str
XML_NS: str
DCORE_NS: str
DCTERMS_NS: str
DCTERMS_PREFIX: str
DOC_NS: str
REL_NS: Any
COMMENTS_NS: Any
IMAGE_NS: Any
VML_NS: Any
VTYPES_NS: Any
XPROPS_NS: Any
EXTERNAL_LINK_NS: Any
PKG_NS: str
PKG_REL_NS: Any
COREPROPS_NS: Any
CONTYPES_NS: Any
XSI_NS: str
SHEET_MAIN_NS: str
CHART_NS: str
DRAWING_NS: str
SHEET_DRAWING_NS: str
CHART_DRAWING_NS: str
CUSTOMUI_NS: str
NAMESPACES: Any
WORKBOOK_MACRO: str
WORKBOOK: str
SPREADSHEET: str
SHARED_STRINGS: Any
EXTERNAL_LINK: Any
WORKSHEET_TYPE: Any
COMMENTS_TYPE: Any
STYLES_TYPE: Any
CHARTSHEET_TYPE: Any
DRAWING_TYPE: str
CHART_TYPE: str
CHARTSHAPE_TYPE: str
THEME_TYPE: str
XLTM: Any
XLSM: Any
XLTX: Any
XLSX: Any
EXT_TYPES: Any
CTRL: str
ACTIVEX: str
VBA: str
