from typing import Any

def prepare_grant_uri(
    uri,
    client_id,
    response_type,
    redirect_uri: Any | None = ...,
    scope: Any | None = ...,
    state: Any | None = ...,
    code_challenge: str | None = ...,
    code_challenge_method: str | None = ...,
    **kwargs,
): ...
def prepare_token_request(
    grant_type, body: str = ..., include_client_id: bool = ..., code_verifier: str | None = ..., **kwargs
): ...
def prepare_token_revocation_request(
    url, token, token_type_hint: str = ..., callback: Any | None = ..., body: str = ..., **kwargs
): ...
def parse_authorization_code_response(uri, state: Any | None = ...): ...
def parse_implicit_response(uri, state: Any | None = ..., scope: Any | None = ...): ...
def parse_token_response(body, scope: Any | None = ...): ...
def validate_token_parameters(params) -> None: ...
