from typing import Any

def extended_operation(request_name, request_value: Any | None = ..., no_encode: Any | None = ...): ...
def extended_request_to_dict(request): ...
def extended_response_to_dict(response): ...
def intermediate_response_to_dict(response): ...
def extended_response_to_dict_fast(response): ...
def intermediate_response_to_dict_fast(response): ...
