from typing import Any

class ObjectDef:
    def __init__(
        self,
        object_class: Any | None = ...,
        schema: Any | None = ...,
        custom_validator: Any | None = ...,
        auxiliary_class: Any | None = ...,
    ) -> None: ...
    def __getitem__(self, item): ...
    def __getattr__(self, item): ...
    def __setattr__(self, key, value) -> None: ...
    def __iadd__(self, other): ...
    def __isub__(self, other): ...
    def __iter__(self): ...
    def __len__(self): ...
    def __bool__(self): ...
    def __contains__(self, item): ...
    def add_from_schema(self, attribute_name, mandatory: bool = ...) -> None: ...
    def add_attribute(self, definition: Any | None = ...) -> None: ...
    def remove_attribute(self, item) -> None: ...
    def clear_attributes(self) -> None: ...
