class UnsupportedFormatException(Exception): ...
class InvalidCarrierException(Exception): ...
class SpanContextCorruptedException(Exception): ...

class Format:
    BINARY: str
    TEXT_MAP: str
    HTTP_HEADERS: str
