def populate(source, source_mapper, dest, dest_mapper, synchronize_pairs, uowcommit, flag_cascaded_pks) -> None: ...
def bulk_populate_inherit_keys(source_dict, source_mapper, synchronize_pairs) -> None: ...
def clear(dest, dest_mapper, synchronize_pairs) -> None: ...
def update(source, source_mapper, dest, old_prefix, synchronize_pairs) -> None: ...
def populate_dict(source, source_mapper, dict_, synchronize_pairs) -> None: ...
def source_modified(uowcommit, source, source_mapper, synchronize_pairs): ...
