from typing import Any

DEFAULT_ROW_HEIGHT: float
BASE_COL_WIDTH: int
DEFAULT_COLUMN_WIDTH: Any
DEFAULT_LEFT_MARGIN: float
DEFAULT_TOP_MARGIN: float
DEFAULT_HEADER: float

def inch_to_dxa(value): ...
def dxa_to_inch(value): ...
def dxa_to_cm(value): ...
def cm_to_dxa(value): ...
def pixels_to_EMU(value): ...
def EMU_to_pixels(value): ...
def cm_to_EMU(value): ...
def EMU_to_cm(value): ...
def inch_to_EMU(value): ...
def EMU_to_inch(value): ...
def pixels_to_points(value, dpi: int = ...): ...
def points_to_pixels(value, dpi: int = ...): ...
def degrees_to_angle(value): ...
def angle_to_degrees(value): ...
def short_color(color): ...
