from collections.abc import Generator
from typing import Any

class WorkbookParser:
    archive: Any
    workbook_part_name: Any
    wb: Any
    keep_links: Any
    sheets: Any
    def __init__(self, archive, workbook_part_name, keep_links: bool = ...) -> None: ...
    @property
    def rels(self): ...
    caches: Any
    def parse(self) -> None: ...
    def find_sheets(self) -> Generator[Any, None, None]: ...
    def assign_names(self) -> None: ...
    @property
    def pivot_caches(self): ...
