from typing import Any

UNQUOTE_PAIRS: Any
unquote: Any
tchar: Any
token: Any
token68: Any
quoted_string: Any
auth_param_name: Any
auth_param: Any
params: Any
scheme: Any
challenge: Any
authentication_info: Any
www_authenticate: Any
