from _typeshed import Incomplete

error: Incomplete
langid: Incomplete

def AddSourceToRegistry(
    appName, msgDLL: Incomplete | None = ..., eventLogType: str = ..., eventLogFlags: Incomplete | None = ...
) -> None: ...
def RemoveSourceFromRegistry(appName, eventLogType: str = ...) -> None: ...
def ReportEvent(
    appName,
    eventID,
    eventCategory: int = ...,
    eventType=...,
    strings: Incomplete | None = ...,
    data: Incomplete | None = ...,
    sid: Incomplete | None = ...,
) -> None: ...
def FormatMessage(eventLogRecord, logType: str = ...): ...
def SafeFormatMessage(eventLogRecord, logType: Incomplete | None = ...): ...
def FeedEventLogRecords(feeder, machineName: Incomplete | None = ..., logName: str = ..., readFlags: Incomplete | None = ...): ...
