from typing import Any

def str_to_datetime_processor_factory(regexp, type_): ...
def py_fallback(): ...
def to_unicode_processor_factory(encoding, errors: Any | None = ...): ...
def to_conditional_unicode_processor_factory(encoding, errors: Any | None = ...): ...
def to_decimal_processor_factory(target_class, scale): ...
