from typing import Any

class _PasslibRegistryProxy:
    __name__: str
    __package__: Any
    def __getattr__(self, attr): ...
    def __setattr__(self, attr, value) -> None: ...
    def __dir__(self): ...

def register_crypt_handler_path(name, path) -> None: ...
def register_crypt_handler(handler, force: bool = ..., _attr: Any | None = ...) -> None: ...
def get_crypt_handler(name, default=...): ...
def list_crypt_handlers(loaded_only: bool = ...): ...
