from markdown.blockprocessors import BlockProcessor
from markdown.extensions import Extension

class MarkdownInHtmlProcessor(BlockProcessor): ...
class MarkdownInHtmlExtension(Extension): ...

def makeExtension(**kwargs): ...
