from typing import Any

from . import _Serialiasable

KEYWORDS: Any
seq_types: Any

class Serialisable(_Serialiasable):
    __attrs__: Any
    __nested__: Any
    __elements__: Any
    __namespaced__: Any
    idx_base: int
    @property
    # TODO: needs overrides in many sub-classes
    # @abstractmethod
    def tagname(self) -> str: ...
    namespace: Any
    @classmethod
    def from_tree(cls, node): ...
    def to_tree(self, tagname: Any | None = ..., idx: Any | None = ..., namespace: Any | None = ...): ...
    def __iter__(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...
    def __hash__(self): ...
    def __add__(self, other): ...
    def __copy__(self): ...
