from _typeshed import Incomplete
from distutils.core import Distribution as _Distribution

from setuptools import SetuptoolsDeprecationWarning

class Distribution(_Distribution):
    def patch_missing_pkg_info(self, attrs) -> None: ...
    package_data: Incomplete
    dist_files: Incomplete
    src_root: Incomplete
    dependency_links: Incomplete
    setup_requires: Incomplete
    def __init__(self, attrs: Incomplete | None = ...) -> None: ...
    def warn_dash_deprecation(self, opt, section): ...
    def make_option_lowercase(self, opt, section): ...
    def parse_config_files(self, filenames: Incomplete | None = ..., ignore_option_errors: bool = ...) -> None: ...
    def fetch_build_eggs(self, requires): ...
    def finalize_options(self): ...
    def get_egg_cache_dir(self): ...
    def fetch_build_egg(self, req): ...
    def get_command_class(self, command): ...
    def print_commands(self): ...
    def get_command_list(self): ...
    def include(self, **attrs) -> None: ...
    packages: Incomplete
    py_modules: Incomplete
    ext_modules: Incomplete
    def exclude_package(self, package) -> None: ...
    def has_contents_for(self, package): ...
    def exclude(self, **attrs) -> None: ...
    def get_cmdline_options(self): ...
    def iter_distribution_names(self) -> None: ...
    def handle_display_options(self, option_order): ...

class DistDeprecationWarning(SetuptoolsDeprecationWarning): ...
