from typing import Any

from .base import DATE, DATETIME, SQLiteDialect

class _SQLite_pysqliteTimeStamp(DATETIME):
    def bind_processor(self, dialect): ...
    def result_processor(self, dialect, coltype): ...

class _SQLite_pysqliteDate(DATE):
    def bind_processor(self, dialect): ...
    def result_processor(self, dialect, coltype): ...

class SQLiteDialect_pysqlite(SQLiteDialect):
    default_paramstyle: str
    supports_statement_cache: bool
    colspecs: Any
    description_encoding: Any
    driver: str
    @classmethod
    def dbapi(cls): ...
    @classmethod
    def get_pool_class(cls, url): ...
    def set_isolation_level(self, connection, level): ...
    def on_connect(self): ...
    def create_connect_args(self, url): ...
    def is_disconnect(self, e, connection, cursor): ...

dialect = SQLiteDialect_pysqlite
