from typing import Any

def pid_exists(pid): ...
def wait_pid(
    pid, timeout: Any | None = ..., proc_name: Any | None = ..., _waitpid=..., _timer=..., _min=..., _sleep=..., _pid_exists=...
): ...
def disk_usage(path): ...
def get_terminal_map(): ...
