class PaymentInstrumentType:
    PayPalAccount: str
    PayPalHere: str
    EuropeBankAccount: str
    CreditCard: str
    ApplePayCard: str
    AndroidPayCard: str
    AmexExpressCheckoutCard: str
    VenmoAccount: str
    UsBankAccount: str
    VisaCheckoutCard: str
    MasterpassCard: str
    SamsungPayCard: str
    LocalPayment: str
