from typing import Any

class TranslatorError(Exception): ...

class Translator:
    tokenizer: Any
    def __init__(self, formula, origin) -> None: ...
    def get_tokens(self): ...
    ROW_RANGE_RE: Any
    COL_RANGE_RE: Any
    CELL_REF_RE: Any
    @staticmethod
    def translate_row(row_str, rdelta): ...
    @staticmethod
    def translate_col(col_str, cdelta): ...
    @staticmethod
    def strip_ws_name(range_str): ...
    @classmethod
    def translate_range(cls, range_str, rdelta, cdelta): ...
    def translate_formula(self, dest: Any | None = ..., row_delta: int = ..., col_delta: int = ...): ...
