from stripe.api_resources.abstract.api_resource import APIResource as APIResource

class SingletonAPIResource(APIResource):
    @classmethod
    def retrieve(cls, **params): ...
    @classmethod
    def class_url(cls): ...
    def instance_url(self): ...
