from collections.abc import Generator
from typing import Any

class MQTTMatcher:
    class Node: ...

    def __init__(self) -> None: ...
    def __setitem__(self, key: str, value: Any) -> None: ...
    def __getitem__(self, key: str) -> Any: ...
    def __delitem__(self, key: str) -> None: ...
    def iter_match(self, topic: str) -> Generator[Any, None, None]: ...
