def sasl_prep(data): ...
def validate_simple_password(password, accept_empty: bool = ...): ...
def abort_sasl_negotiation(connection, controls): ...
def send_sasl_negotiation(connection, controls, payload): ...
def random_hex_string(size): ...
